// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
//
// See the LICENSE.txt file for license information. Please report all
// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.

#ifndef MESH_GFACE_QUADRILATERALIZE
#define MESH_GFACE_QUADRILATERALIZE

class GFace;
int gmshQMorph(GFace *gf);

#endif
